static const char *script_lib_sprite_string =
  "Sprite.SetPosition = fun (x, y, z)\n"
  "{\n"
  "  this.SetX(x);\n"
  "  this.SetY(y);\n"
  "  this.SetZ(z);\n"
  "};\n"
  "\n"
  "Sprite |= fun (image)\n"
  "{\n"
  "  new_sprite = Sprite._New() | [] | Sprite;\n"
  "  if (image) new_sprite.SetImage(image);\n"
  "  return new_sprite;\n"
  "};\n"
  "\n"
  "#------------------------- Compatability Functions -------------------------\n"
  "\n"
  "fun SpriteNew ()\n"
  "{\n"
  "  return Sprite ();\n"
  "}\n"
  "\n"
  "fun SpriteSetImage (sprite, image)\n"
  "{\n"
  "  return sprite.SetImage (image);\n"
  "}\n"
  "\n"
  "fun SpriteSetX (sprite, value)\n"
  "{\n"
  "  return sprite.SetX (value);\n"
  "}\n"
  "\n"
  "fun SpriteSetY (sprite, value)\n"
  "{\n"
  "  return sprite.SetY (value);\n"
  "}\n"
  "\n"
  "fun SpriteSetZ (sprite, value)\n"
  "{\n"
  "  return sprite.SetZ (value);\n"
  "}\n"
  "\n"
  "fun SpriteSetPosition (sprite, x, y, z)\n"
  "{\n"
  "  sprite.SetX(x);\n"
  "  sprite.SetY(y);\n"
  "  sprite.SetZ(z);\n"
  "}\n"
  "\n"
  "fun SpriteSetOpacity (sprite, value)\n"
  "{\n"
  "  return sprite.SetOpacity (value);\n"
  "}\n"
  "\n"
  "\n"
  "fun SpriteWindowGetWidth ()\n"
  "{\n"
  "  return Window.GetWidth ();\n"
  "}\n"
  "\n"
  "\n"
  "fun SpriteWindowGetHeight ()\n"
  "{\n"
  "  return Window.GetHeight ();\n"
  "}\n"
  "\n"
  "\n"
  "fun SpriteWindowSetBackgroundTopColor (red, green, blue)\n"
  "{\n"
  "  return Window.SetBackgroundTopColor (red, green, blue);\n"
  "}\n"
  "\n"
  "\n"
  "fun SpriteWindowSetBackgroundBottomColor (red, green, blue)\n"
  "{\n"
  "  return Window.SetBackgroundBottomColor (red, green, blue);\n"
  "}\n"
  "\n"
;
