static const char *script_lib_math_string =
  "Math.Abs = fun (value)\n"
  "{\n"
  "  if (value < 0) return -value;\n"
  "  return value;\n"
  "};\n"
  "\n"
  "Math.Min = fun (value_a, value_b)\n"
  "{\n"
  "  if (value_a < value_b) return value_a;\n"
  "  return value_b;\n"
  "};\n"
  "\n"
  "Math.Max = fun (value_a, value_b)\n"
  "{\n"
  "  if (value_a > value_b) return value_a;\n"
  "  return value_b;\n"
  "};\n"
  "\n"
  "Math.Clamp = fun (value, min, max)\n"
  "{\n"
  "  if (value < min) return min;\n"
  "  if (value > max) return max;\n"
  "  return value;\n"
  "};\n"
  "\n"
  "Math.Pi = 3.14159265358979323846;\n"
  "\n"
  "#------------------------- Compatability Functions -------------------------\n"
  "\n"
  "MathAbs = Math.Abs;\n"
  "MathMin = Math.Min;\n"
  "MathMax = Math.Max;\n"
  "MathClamp = Math.Clamp;\n"
  "MathPi = Math.Pi;\n"
  "MathCos = Math.Cos;\n"
  "MathSin = Math.Sin;\n"
  "MathTan = Math.Tan;\n"
  "MathATan2 = Math.ATan2;\n"
  "MathSqrt = Math.Sqrt;\n"
  "MathInt = Math.Int;\n"
;
